@@ -317,6 +317,7 @@ impl Einsum {
     }
 
     #[staticmethod]
+    #[args(nodes = "*", name)]
     pub fn from_einsum_string(
         string: &str,
         nodes: Vec<CircuitRc>,
@@ -327,6 +328,7 @@ impl Einsum {
     }
 
     #[staticmethod]
+    #[args(nodes = "*", name)]
     pub fn from_fancy_string(
         string: &str,
         nodes: Vec<CircuitRc>,
@@ -349,12 +351,13 @@ impl Einsum {
     }
 
     #[staticmethod]
+    #[args(nodes = "*", name)]
     pub fn from_spec_py(
         spec: EinsumSpec,
-        circuits: Vec<CircuitRc>,
+        nodes: Vec<CircuitRc>,
         name: Option<String>,
     ) -> Result<Self, CircuitConstructionError> {
-        Self::try_from_spec(&spec, &circuits, name)
+        Self::try_from_spec(&spec, &nodes, name)
     }
 
     #[getter]
@@ -420,6 +423,7 @@ impl Einsum {
         .unwrap()
     }
     #[staticmethod]
+    #[args(nodes = "*")]
     pub fn elementwise_broadcasted(
         nodes: Vec<CircuitRc>,
         name: Option<String>,
