@@ -29,7 +29,7 @@ pub static PY_CIRCUIT_ITEMS: GILLazyPy<PyCircuitItems> = GILLazyPy::new_py(|py|
     PyCircuitItems {
         computational_node: get("computational_node"),
         constant: get("constant"),
-        rust_to_py: interop.getattr(py, "rust_to_py").unwrap().into(),
+        rust_to_py: interop.getattr(py, "rust_to_py").unwrap(),
         interop,
         circ_compiler_util: get("circ_compiler_util"),
     }
