@@ -29,14 +29,12 @@ pub fn scatter_fuse(scatter: &Scatter) -> Option<Scatter> {
     // this is just composing indices, lower is top
     if let Circuit::Scatter(inner) = &**scatter.node {
         let index_composed = compose(&inner.index, &scatter.index)?;
-        Some(
-            Scatter::new(
-                inner.node.clone(),
-                index_composed,
-                scatter.info().shape.clone(),
-                scatter.name_cloned(),
-            ),
-        )
+        Some(Scatter::new(
+            inner.node.clone(),
+            index_composed,
+            scatter.info().shape.clone(),
+            scatter.name_cloned(),
+        ))
     } else {
         None
     }
@@ -114,15 +112,12 @@ pub fn einsum_pull_scatter(einsum: &Einsum) -> Option<CircuitRc> {
             })
             .collect();
         let new_einsum = Einsum::nrc(new_args, einsum.out_axes.clone(), einsum.name_cloned());
-        Some(
-            Scatter::nrc(
-                new_einsum,
-                uslice_map_get_index(&einsum.out_axes, &int_slices)
-                    .canonicalize(&einsum.info().shape),
-                einsum.info().shape.clone(),
-                None,
-            ),
-        )
+        Some(Scatter::nrc(
+            new_einsum,
+            uslice_map_get_index(&einsum.out_axes, &int_slices).canonicalize(&einsum.info().shape),
+            einsum.info().shape.clone(),
+            None,
+        ))
     }
 }
 
@@ -187,14 +182,12 @@ pub fn add_pull_scatter(add: &Add) -> Option<Scatter> {
             })
             .collect();
         let new_add = Add::nrc(new_operands, add.name_cloned());
-        Some(
-            Scatter::new(
-                new_add,
-                uslices_to_index(&(0..add.info().rank()).map(|i| slices[i]).collect()),
-                add.info().shape.clone(),
-                None,
-            ),
-        )
+        Some(Scatter::new(
+            new_add,
+            uslices_to_index(&(0..add.info().rank()).map(|i| slices[i]).collect()),
+            add.info().shape.clone(),
+            None,
+        ))
     }
 }
 
@@ -275,22 +268,20 @@ pub fn index_einsum_to_scatter(node: &Index) -> Option<CircuitRc> {
                 new_shape,
                 None,
             );
-            Some(
-                Index::nrc(
-                    new_scatter,
-                    TensorIndex(
-                        node.index
-                            .0
-                            .iter()
-                            .map(|x| match x {
-                                TensorAxisIndex::Single(_x) => TensorAxisIndex::Single(0),
-                                _ => TensorAxisIndex::IDENT,
-                            })
-                            .collect(),
-                    ),
-                    None,
+            Some(Index::nrc(
+                new_scatter,
+                TensorIndex(
+                    node.index
+                        .0
+                        .iter()
+                        .map(|x| match x {
+                            TensorAxisIndex::Single(_x) => TensorAxisIndex::Single(0),
+                            _ => TensorAxisIndex::IDENT,
+                        })
+                        .collect(),
                 ),
-            )
+                None,
+            ))
         }
     } else {
         None
@@ -316,24 +307,21 @@ pub fn scatter_pull_removable_axes(scatter: &Scatter) -> Option<Rearrange> {
         None
     } else {
         let new_inner = remove_axes(&scatter.node, &removable_axes).unwrap();
-        Some(
-            Rearrange::new(
-                Scatter::nrc(
-                    new_inner,
-                    TensorIndex(filter_out_idx(&scatter.index.0, &removable_axes)),
-                    filter_out_idx(
-                        &scatter.info().shape.iter().cloned().collect::<Vec<_>>(),
-                        &removable_axes,
-                    )
-                    .into_iter()
-                    .collect(),
-                    None,
-                ),
-                RearrangeSpec::unremove_axes(&removable_axes, &scatter.info().shape),
+        Some(Rearrange::new(
+            Scatter::nrc(
+                new_inner,
+                TensorIndex(filter_out_idx(&scatter.index.0, &removable_axes)),
+                filter_out_idx(
+                    &scatter.info().shape.iter().cloned().collect::<Vec<_>>(),
+                    &removable_axes,
+                )
+                .into_iter()
+                .collect(),
                 None,
-            )
-            ,
-        )
+            ),
+            RearrangeSpec::unremove_axes(&removable_axes, &scatter.info().shape),
+            None,
+        ))
     }
 }
 
@@ -401,5 +389,10 @@ pub fn concat_to_scatter(concat: &Concat) -> Option<Scatter> {
     if new_concat.info().numel() == concat.info().numel() {
         return None;
     }
-    Some(Scatter::new(new_concat, scatter_index, concat.info().shape.clone(), None))
+    Some(Scatter::new(
+        new_concat,
+        scatter_index,
+        concat.info().shape.clone(),
+        None,
+    ))
 }
